@@ -181,6 +181,7 @@ codecs.open(OUTPUTFILE, mode='a', encoding='utf8') as fout:
                 matchAdded = RE_ADDED.search(lineout, next_pos) # redo matching for updated text
 
             next_pos = 0
+            matchDeleted = RE_DELETED.search(lineout, next_pos)  # redo matching for (potentially) updated text
             while matchDeleted:
                 if FLAG_FAST_BREAK:
                     break
@@ -201,6 +202,7 @@ codecs.open(OUTPUTFILE, mode='a', encoding='utf8') as fout:
                 matchDeleted = RE_DELETED.search(lineout, next_pos)
 
             next_pos = 0
+            matchReplaced = RE_REPLACED.search(lineout, next_pos)  # redo matching for (potentially) updated text
             while matchReplaced:
                 if FLAG_FAST_BREAK:
                     break
@@ -227,6 +229,7 @@ codecs.open(OUTPUTFILE, mode='a', encoding='utf8') as fout:
                 matchReplaced = RE_REPLACED.search(lineout, next_pos)
 
             next_pos = 0
+            matchHighlight = RE_HIGHLIGHT.search(lineout, next_pos)  # redo matching for (potentially) updated text
             while matchHighlight:
                 if FLAG_FAST_BREAK:
                     break
@@ -247,6 +250,7 @@ codecs.open(OUTPUTFILE, mode='a', encoding='utf8') as fout:
                 matchHighlight = RE_HIGHLIGHT.search(lineout, next_pos)
 
             next_pos = 0
+            matchComment = RE_COMMENT.search(lineout, next_pos)  # redo matching for (potentially) updated text
             while matchComment:
                 if FLAG_FAST_BREAK:
                     break
